Description Usage Arguments Examples
This function let you plot a map with drawn coast boundary, using a scico colorscale.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 |
data |
Data to be ploted, 2d matrix |
lon |
Longitude data, 2d matrix. Defaults to lonFenno. |
lat |
Latitude data, 2d matrix. Defaults to latFenno. |
title |
Title of plot. Defaults to "". |
season |
Small text in upper corner of plot, for example to specify what season the data is from. Defaults to "". |
seasonSize |
Text size of taxt passed to season argument. Defaults to 1. |
m |
Supply mean to print in lower corner. Defaults to "" |
xlim |
To limit map area in x direction. Defaults to [55, 32]. |
ylim |
To limit map area in y direction. Defaults to [5, 73]. |
z |
To set a scale for the colorbar. Defaults to ". |
colScale |
What type of scico colorscale to use. Defaults to "roma". |
legend |
If T plot legend using image.plot, else ploting using poly.image. Defaults to True |
lWidth |
Width of legend. Defaults to 4 |
1 | plotMap()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.